from .core import AbstractSAS
from .globals import sasma_sasobjsp_host, sasma_sasobjsp_port


class SASMA(AbstractSAS):
    """
    This class is a wrapper for saspy.SASSession.
    It hides all the 'tricky' parts of establishing connection with SASMA.
    """
    def __init__(self, user,
                       password,
                       sasobjsp_host=sasma_sasobjsp_host,
                       sasobjsp_port=sasma_sasobjsp_port,  **kwargs):
        """
        Establishes sas connection.
        :param user: user, that is used to connect to SASMA.
        :param password: The password.
        :param sasobjsp_host: Host, on which SAS Object spawner is running.
        :param sasobjsp_port: Port, on which SAS Object spawner is running.
        :param kwargs:
        """
        self.platform = 'SASMA'
        self.env_type = 'Prod'
        super(SASMA, self).__init__(sasobjsp_host=sasobjsp_host,
                                    sasobjsp_port=sasobjsp_port,
                                    sasobjsp_user=user,
                                    sasobjsp_pass=password,
                                    **kwargs)



import os

# Default Java
java_linux = '/usr/bin/java'  # fetch it from env vars???
java_windows = 'java'

# SAS globals...
all_obj_types = ['DeployedFlow', 'DeployedJob', 'ExternalFile', 'Folder',
                     'Library', 'Role', 'Server', 'StoredProcess', 'Table',
                     'User', 'Job']


#**********************************
# Default platfrom settings
###################################
# SASMA
###################################
sasma_sasobjsp_host = 'vs246.imb.ru'
sasma_sasobjsp_port = '8591'

##################################
# SAS Scoring
###################################
sascs_sasobjsp_host = 'vs2458.imb.ru'
sascs_sasobjsp_port = '8591'
#**********************************


###################################
# HashicorpVault settings variables
###################################
hvac_url = 'https://hvault.intranet'
hvac_token_env_var = 'HVAC_TOKEN'
hvac_token = os.environ.get(hvac_token_env_var, default=None)
hvac_role_id_env_var = 'HVAC_ROLE_ID'
hvac_role_id = os.environ.get(hvac_role_id_env_var, default=None)
hvac_secret_env_var = 'HVAC_SECRET_ID'
hvac_secret_id = os.environ.get(hvac_secret_env_var, default=None)
hvac_connections_path = 'Data_Science/dlake/airflow/connections/'
hvac_connections_mountpoint = 'CDO/'



from .core import AbstractSAS
from .globals import sascs_sasobjsp_host, sascs_sasobjsp_port


class SASCS(AbstractSAS):
    def __init__(self, user,
                       password,
                       sasobjsp_host=sascs_sasobjsp_host,
                       sasobjsp_port=sascs_sasobjsp_port,  **kwargs):
        self.platform = 'SASCS'
        self.env_type = 'Prod'
        super(SASCS, self).__init__(sasobjsp_host=sasobjsp_host,
                                    sasobjsp_port=sasobjsp_port,
                                    sasobjsp_user=user,
                                    sasobjsp_pass=password,
                                    **kwargs)
